@@ -19,7 +19,6 @@
 
 #import <AppKit/AppKit.h>
 #import "DictConnection.h"
-#import "DefinitionWriter.h"
 #import "HistoryManager.h"
 
 @interface AppController : NSObject
@@ -29,9 +28,8 @@
   NSTextView* searchResultView;
   NSButton* browseBackButton;
   NSButton* browseForwardButton;
-  NSWindow* dictionaryContentWindow;
   
-  NSMutableArray* dictionaries;
+  DictConnection* dict;
   HistoryManager* historyManager;
 }
 
@@ -41,7 +39,6 @@
 // Some methods called by the GUI
 -(void) browseBackClicked: (id)sender;
 -(void) browseForwardClicked: (id)sender;
--(void) orderFrontPreferencesPanel: (id)sender;
 
 
 // TextView delegate stuff
@@ -51,27 +48,16 @@
 
 -(void)updateGUI;
 
-
-
-// The file to store the dictionary list to
--(NSString*) dictionaryStoreFile;
-
-
-
 // Listen for actions...
 
 // ...from the GUI
--(void) searchAction: (id)sender;
+-(void)searchAction: (id)sender;
 
 // ...from the Links in the text field
--(void) clickSearchNotification: (NSNotification*)aNotification;
-
-// ..from the system
--(void) applicationWillTerminate: (NSNotification*) theNotification;
--(void) applicationDidFinishLaunching: (NSNotification*) theNotification;
+-(void)clickSearchNotification: (NSNotification*)aNotification;
 
 
--(void) defineWord: (NSString*)aWord;
+-(void)defineWord: (NSString*)aWord;
 
 @end
 
@@ -91,6 +77,7 @@
 
 @end
 
+
 @interface AppController (HistoryManagerDelegate) <HistoryManagerDelegate>
 -(BOOL) historyManager: (HistoryManager*) aHistoryManager
 	 needsBrowseTo: (id) aLocation;
