@@ -17,15 +17,12 @@
  */
 
 #import <AppKit/AppKit.h>
-#import <Foundation/Foundation.h>
 
 #import "AppController.h"
 #import "GNUstep.h"
 
 #import "DictConnection.h"
-#import "LocalDictionary.h"
 #import "NSString+Clickable.h"
-#import "Preferences.h"
 
 NSDictionary* bigHeadlineAttributes;
 NSDictionary* headlineAttributes;
@@ -47,16 +44,6 @@ NSDictionary* normalAttributes;
 
 @implementation AppController (DefinitionWriter)
 
--(void) beginWriting
-{
-  // TODO: For multithreaded dictionary entry fetching, lock access here!
-}
-
--(void) endWriting
-{
-  // TODO: For multithreaded dictionary entry fetching, unlock access here!
-}
-
 -(void) clearResults
 {
   NSAttributedString* emptyAttrStr = [[NSAttributedString alloc] init];
@@ -65,7 +52,7 @@ NSDictionary* normalAttributes;
 }
 
 -(void) writeString: (NSString*) aString
-        attributes: (NSDictionary*) attributes
+	 attributes: (NSDictionary*) attributes
 {
   NSAttributedString* attrStr =
     [[NSAttributedString alloc]
@@ -198,8 +185,6 @@ NSDictionary* normalAttributes;
 @end // AppController (DefinitionWriter)
 
 
-
-
 // FIXME: Just for clean programming style: dealloc is missing,
 //        but I think it's not needed.
 
@@ -208,53 +193,17 @@ NSDictionary* normalAttributes;
 -(id)init
 {
   if (self = [super init]) {
-    id dict;
+    dict = [[DictConnection alloc] init];
+    [dict setDefinitionWriter: self];
     
-    // create mutable dictionaries array
-    dictionaries = [[NSMutableArray alloc] initWithCapacity: 2];
-    
-    NSString* dictStoreFile = [self dictionaryStoreFile];
-    
-    if ([[NSFileManager defaultManager] fileExistsAtPath: dictStoreFile]) {
-        NSArray* plist = [NSArray arrayWithContentsOfFile: [self dictionaryStoreFile]];
-        int i;
-        for (i=0; i<[plist count]; i++) {
-            DictionaryHandle* dict =
-                [DictionaryHandle dictionaryFromPropertyList: [plist objectAtIndex: i]];
-            [dict setDefinitionWriter: self];
-            [dictionaries addObject: dict];
-            NSLog(@" *** Added %@", dict);
-        }
-        NSLog(@" *** result: %@", dictionaries);
-    } else {
-#ifdef PREDEFINED_DICTIONARIES // predefined dictionaries
-        // create local dictionary object
-        dict = [[LocalDictionary alloc] initWithResourceName: @"jargon"];
-        [dict setDefinitionWriter: self];
-        [dictionaries addObject: dict];
-        [dict release];
-#ifdef REMOTE_DICTIONARIES // remote dictionaries
-        // create remote dictionary object
-        dict = [[DictConnection alloc] init];
-        [dict setDefinitionWriter: self];
-        [dictionaries addObject: dict];
-        [dict release];
-#endif // end remote dictionaries block
-#endif // end predefined dictionaries
-    }
-    
-    
-    // create history manager
     historyManager = [[HistoryManager alloc] init];
     [historyManager setDelegate: self];
   }
   
-  
-  // create fonts
   if (bigHeadlineAttributes == nil) {
     bigHeadlineAttributes = 
       [[NSDictionary alloc]
-	  initWithObjectsAndKeys:
+	initWithObjectsAndKeys:
 	  [NSFont titleBarFontOfSize: 16], NSFontAttributeName,
 	nil
        ];
@@ -278,11 +227,8 @@ NSDictionary* normalAttributes;
        ];
   }
   
-  // Notifications --------------
-  NSNotificationCenter* defaultCenter = [NSNotificationCenter defaultCenter];
-  
   // Register in the default notification center to receive link clicked events
-  [defaultCenter
+  [[NSNotificationCenter defaultCenter]
     addObserver: self
     selector: @selector(clickSearchNotification:)
     name: WordClickedNotificationType
@@ -292,9 +238,6 @@ NSDictionary* normalAttributes;
 }
 
 
-
-
-
 // ---- Some methods called by the GUI
 -(void) browseBackClicked: (id)sender {
   [historyManager browseBack];
@@ -304,11 +247,6 @@ NSDictionary* normalAttributes;
   [historyManager browseForward];
 }
 
--(void) orderFrontPreferencesPanel: (id)sender {
-    [[Preferences shared] setDictionaries: dictionaries];
-    [[Preferences shared] show];
-}
-
 -(void)updateGUI {
   if ([historyManager canBrowseBack]) {
     [browseBackButton setEnabled: YES];
@@ -389,8 +327,6 @@ NSDictionary* normalAttributes;
   }
 }
 
-
-
 /**
  * Searches for definitions of the word given in the aWord
  * parameter and shows the results in the text view.
@@ -404,101 +340,29 @@ NSDictionary* normalAttributes;
     [searchStringControl setStringValue: aWord];
   }
   
-  // We need space for new content
-  [self clearResults];
-  
-  // Iterate over all dictionaries, query them!
-  int i;
-  
-  for (i=0; i<[dictionaries count]; i++) {
-    id dict = [dictionaries objectAtIndex: i];
-    
-    if ([dict isActive]) {
-        NS_DURING
-          {
-	    [dict open];
-	    [dict sendClientString: @"GNUstep DictionaryReader.app"];
-	    [dict definitionFor: aWord];
-	    [dict close]; // FIXME: That crashes!
-          }
-        NS_HANDLER
-          {
-	    NSRunAlertPanel
-	      (
-	       @"Word definition failed.",
-	       [NSString
-	         stringWithFormat:
-	           @"The definition of %@ failed because of this exception:\n%@",
-	         aWord, [localException reason]],
-	       @"Argh", nil, nil);
-          }
-        NS_ENDHANDLER;
+  NS_DURING
+    {
+      [dict open];
+      [dict sendClientString: @"GNUstep DictionaryReader.app"];
+      [dict definitionFor: aWord];
+      // [dict close]; // FIXME: That crashes!
+      
+      [historyManager browser: self
+		      didBrowseTo: aWord];
+      [self updateGUI];
     }
-  }
-  
-  [historyManager browser: self
-		  didBrowseTo: aWord];
-  
-  [self updateGUI];
-  
-  [dictionaryContentWindow orderFront: self];
-}
-
-
--(NSString*) dictionaryStoreFile
-{
-#warning FIXME: Ensure that directory exists!
-    return [@"~/GNUstep/Library/DictionaryReader/dictionaries.plist"
-                stringByExpandingTildeInPath];
-}
-
--(void) applicationWillTerminate: (NSNotification*) theNotification
-{
-    int i;
-    NSMutableArray* mut = [NSMutableArray arrayWithCapacity: [dictionaries count]];
-    
-    for (i=0; i<[dictionaries count]; i++) {
-        [mut addObject: [[dictionaries objectAtIndex: i] shortPropertyList]];
+  NS_HANDLER
+    {
+      NSRunAlertPanel
+	(
+	 @"Word definition failed.",
+	 [NSString
+	   stringWithFormat:
+	     @"The definition of %@ failed because of this exception:\n%@",
+	   aWord, [localException reason]],
+	 @"Argh", nil, nil);
     }
-    
-    [mut writeToFile: [self dictionaryStoreFile] atomically: YES];
-}
-
--(void) applicationDidFinishLaunching: (NSNotification*) theNotification
-{
-    [NSApp setServicesProvider: self];
-}
-
-
-/**
- * The Dictionary Lookup service:
- * Takes a string from the calling application and looks it up.
- * Written by Chris B. Vetter
- */
-- (void) lookupInDictionary: (NSPasteboard *) pboard
-                   userData: (NSString *) userData
-                      error: (NSString **) error
-{
-  NSString *aString = nil;
-  NSArray *allTypes = nil;
-  
-  allTypes = [pboard types];
-  
-  if ( ![allTypes containsObject: NSStringPboardType] )
-  {
-    *error = @"No string type supplied on pasteboard";
-    return;
-  }
-  
-  aString = [pboard stringForType: NSStringPboardType];
-  
-  if (aString == nil)
-  {
-    *error = @"No string value supplied on pasteboard";
-    return;
-  }
-  
-  [self defineWord: aString];
+  NS_ENDHANDLER;
 }
 
 @end // AppController
